#include <avr/io.h>
#include <avr/interrupt.h>
 
#include <util/delay.h>
#include "rc5.h"
#define AREF 5

#define IR_FWD 16
#define IR_BCK 17
#define IR_LFT 21
#define IR_RGT 22

/*
 * Initializes input and output ports.
 */
void init_ports(void)
{	
    /* PORTB is used for output */
    DDRB = 0xFF;
    PORTB = 0x00;

 	TCCR0A |= (1 << WGM01) | (1 << WGM00);
	TCCR0B |= (1 << WGM02);
	TCCR0B |= (1 << CS02) | (1 << CS00);
	TIMSK0 |= (1 << OCIE0B) | (1 << TOIE0);
	OCR0A = 0xFA;
	OCR0B = 0xFF;
}

int main(void)
{	
    //init_ports();
	RC5_Init();
	
    /* enable interrupts */
    sei();
 
    /* PWM fill-rate set to 50% */
    OCR1A = 65535 / 2;
    OCR1B = 65535 / 2;
   
	PORTB |= _BV(PB0);
	
    while (1) {
		uint16_t command;
		//PORT &= ~_BV(PD0);
                
        /* Poll for new RC5 command */
        if(RC5_NewCommandReceived(&command))
        {
            /* Reset RC5 lib so the next command
             * can be decoded. This is a must! */
            RC5_Reset();
            
            /* Toggle the LED on PB5 */
            PORTB ^= _BV(PB0);
            
            uint8_t toggle = RC5_GetToggleBit(command);
            uint8_t address = RC5_GetAddressBits(command);
            uint8_t cmdnum = RC5_GetCommandBits(command);
			
			if (cmdnum == IR_FWD) {
                //forward
                PORTB = _BV(PB7) | _BV(PB6) | _BV(PB5) | _BV(PB3);
			} else if (cmdnum == IR_LFT) {
                //left
                PORTB &= ~_BV(PB3);
                PORTB |= _BV(PB7) | _BV(PB6) | _BV(PB5);			
			} else if (cmdnum == IR_RGT) {
                //right
                PORTB &= ~_BV(PB5);
                PORTB |= _BV(PB7) | _BV(PB6) | _BV(PB3);
			} else {
				PORTB &= ~_BV(PB3);
				PORTB &= ~_BV(PB5);
			}
        }
		_delay_ms(200);
	}
 
    return 0;
}